@@ -12,7 +12,7 @@ import soco
 
 from soco_cli.action_processor import list_actions
 from soco_cli.aliases import AliasManager
-from soco_cli.api import run_command
+from soco_cli.api import get_all_speakers, run_command
 from soco_cli.check_for_update import print_update_status
 from soco_cli.cmd_parser import CLIParser
 from soco_cli.interactive import interactive_loop
@@ -26,7 +26,7 @@ from soco_cli.utils import (
     convert_to_seconds,
     create_speaker_cache,
     docs,
-    error_and_exit,
+    error_report,
     get_speaker,
     logo,
     seconds_until,
@@ -201,14 +201,12 @@ def main():
 
     message = check_args(args)
     if message:
-        error_and_exit(message)
+        error_report(message)
 
     use_local_speaker_list = args.use_local_speaker_list
     if env.get(ENV_LOCAL) == "TRUE" and not args.no_env:
         logging.info(
-            "Env. var. '{}' set to 'TRUE ... using local speaker list".format(
-                ENV_LOCAL
-            )
+            "Env. var. '{}' set to 'TRUE ... using local speaker list".format(ENV_LOCAL)
         )
         use_local_speaker_list = True
     if use_local_speaker_list:
@@ -240,7 +238,7 @@ def main():
             logging.info("No 'SPKR' environment variable set")
 
     if args.interactive:
-        sk = True if args.sk else False
+        sk = bool(args.sk)
         speaker_name = None
         if len(args.parameters):
             speaker_name = args.parameters[0]
@@ -275,7 +273,7 @@ def main():
             # Special case: the 'loop_to_start' action
             if speaker_name.lower() == "loop_to_start":
                 if len(sequence) != 1:
-                    error_and_exit("Action 'loop_to_start' takes no parameters")
+                    error_report("Action 'loop_to_start' takes no parameters")
                 # Reset pointers, rewind and continue
                 loop_pointer = -1
                 sequence_pointer = 0
@@ -295,7 +293,7 @@ def main():
                                 "Looping for {} iteration(s)".format(loop_iterator)
                             )
                         except ValueError:
-                            error_and_exit(
+                            error_report(
                                 "Action 'loop' takes no parameters, or a number of iterations (> 0)"
                             )
                     loop_iterator -= 1
@@ -314,7 +312,7 @@ def main():
             # Special case: the 'loop_for' action
             if speaker_name.lower() == "loop_for":
                 if len(sequence) != 2:
-                    error_and_exit(
+                    error_report(
                         "Action 'loop_for' requires one parameter (check spaces around the ':' separator)"
                     )
                 loop_duration = 0
@@ -323,7 +321,7 @@ def main():
                     try:
                         loop_duration = convert_to_seconds(sequence[1])
                     except ValueError:
-                        error_and_exit(
+                        error_report(
                             "Action 'loop_for' requires one parameter (duration >= 0)"
                         )
                     logging.info(
@@ -349,7 +347,7 @@ def main():
             if speaker_name.lower() == "loop_until":
                 loop_duration = 0
                 if len(sequence) != 2:
-                    error_and_exit(
+                    error_report(
                         "Action 'loop_until' requires one parameter (check spaces around the ':' separator)"
                     )
                 if loop_start_time is None:
@@ -357,7 +355,7 @@ def main():
                     try:
                         loop_duration = seconds_until(sequence[1])
                     except:
-                        error_and_exit(
+                        error_report(
                             "Action 'loop_until' requires one parameter (stop time)"
                         )
                     logging.info(
@@ -396,7 +394,7 @@ def main():
 
             # General action processing
             if len(sequence) < 2:
-                error_and_exit(
+                error_report(
                     "At least 2 parameters required in action sequence '{}'".format(
                         sequence
                     )
@@ -407,7 +405,7 @@ def main():
                 if use_local_speaker_list:
                     speakers = speaker_list.get_all_speakers()
                 else:
-                    speakers = soco.discovery.any_soco().all_zones
+                    speakers = get_all_speakers(use_scan=True)
                 logging.info(
                     "Performing action '{}' on all visible, coordinator speakers".format(
                         action
@@ -420,15 +418,18 @@ def main():
                                 action, speaker.player_name
                             )
                         )
-                        print(speaker.player_name)
+                        print(speaker.player_name + ": ", end="", flush=True)
                         exit_code, output_msg, error_msg = run_command(
                             speaker,
                             action,
                             *args,
                             use_local_speaker_list=use_local_speaker_list,
                         )
-                        if exit_code == 0 and len(output_msg) != 0:
-                            print(output_msg, flush=True)
+                        if exit_code == 0:
+                            if len(output_msg) != 0:
+                                print(output_msg, flush=True)
+                            else:
+                                print("OK", flush=True)
                         elif len(error_msg) != 0:
                             print(error_msg, file=sys.stderr, flush=True)
                         cumulative_exit_code += exit_code
@@ -478,5 +479,5 @@ if __name__ == "__main__":
         main()
         exit(0)
     except Exception as error:
-        error_and_exit(str(error))
+        error_report(str(error))
         exit(1)
